@@ -4,7 +4,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use File::Spec::Functions qw(splitdir updir catdir file_name_is_absolute);
 use Cwd qw(abs_path);
 
-our $VERSION = '0.4';
+our $VERSION = '0.5';
 
 sub register {
     my ($self, $app, $conf) = @_;
@@ -69,10 +69,9 @@ sub register {
         $r->get($root.'(*file)' => {prefix => 'source', file => 'index.html' } => $static_cb);
     }
     else {
-        $r->get($root.'(*file)' => {file => 'index.html' } => sub {
-             my $self = shift;
-             my $file = $self->param('file');
-             $self->req->url->path('/'.$file);
+        # redirect root to index.html
+        $r->get($root => sub {
+             $self->req->url->path('/index.html');
              return $app->static->dispatch($self);
         });
      }
